summaryrefslogtreecommitdiffstats
path: root/src/resultlistviewtext.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/resultlistviewtext.h')
-rw-r--r--src/resultlistviewtext.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/resultlistviewtext.h b/src/resultlistviewtext.h
index 088f9e5..d5c90f8 100644
--- a/src/resultlistviewtext.h
+++ b/src/resultlistviewtext.h
@@ -27,16 +27,16 @@ class TQColorGroup;
class TQFontMetrics;
// This class shows the results shown in the MainWindow result pane.
-class ResultListViewText : public KListViewItem
+class ResultListViewText : public TDEListViewItem
{
public:
- ResultListViewText(KListView *listView,
+ ResultListViewText(TDEListView *listView,
const TQString &text,
const TQString &result,
ResultListViewText *after,
bool isError = false);
- ResultListViewText(KListView *listView,
+ ResultListViewText(TDEListView *listView,
const TQString &text,
const Abakus::number_t &result,
ResultListViewText *after,
@@ -53,7 +53,7 @@ class ResultListViewText : public KListViewItem
// Redisplays the text by calling value.toString again.
void precisionChanged();
// Reimplemented from KListViewItem
virtual void paintCell(TQPainter *p, const TQColorGroup &cg, int column, int width, int align);
virtual int width(const TQFontMetrics &fm, const TQListView *lv, int c) const;
@@ -53,7 +53,7 @@ class ResultListViewText : public KListViewItem
// Redisplays the text by calling value.toString again.
void precisionChanged();
- // Reimplemented from KListViewItem
+ // Reimplemented from TDEListViewItem
virtual void paintCell(TQPainter *p, const TQColorGroup &cg, int column, int width, int align);
virtual int width(const TQFontMetrics &fm, const TQListView *lv, int c) const;